@@ -2,8 +2,8 @@
 #define MAINWINDOW_H
 
 #include "keylistener.h"
+#include "bcprocess.h"
 #include <QMainWindow>
-#include <QProcess>
 
 namespace Ui {
     class MainWindow;
@@ -16,13 +16,15 @@ class MainWindow : public QMainWindow
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
-
-protected:
-    void appendChar(QChar c);
+    void append(QChar c);
+    void append(QString s);
+    void setIbase(int value);
+    void setObase(int value);
+    void setScale(int value);
 
 private:
     Ui::MainWindow *ui;
-    QProcess bc;
+    BcProcess bc;
 
 private slots:
     void on_pb0_clicked();
@@ -46,7 +48,8 @@ private slots:
     void on_pbFn_clicked();
     void on_pbVariable_clicked();
     void on_pbEnter_clicked();
-    void displayOutput();
+    void displayOutput(QString text);
+    void displayError(QString text);
 
 protected:
     KeyListener* keyListener;
